@@ -4,7 +4,7 @@ from datetime import datetime
 import factory
 import random
 
-class PollFactory(factory.Factory):
+class PollFactory(factory.DjangoModelFactory):
     FACTORY_FOR = Poll
 
     owner = factory.SubFactory(UserFactory)
@@ -14,7 +14,7 @@ class PollFactory(factory.Factory):
     votes_count = 0
     answer_id = 0
 
-class AnswerFactory(factory.Factory):
+class AnswerFactory(factory.DjangoModelFactory):
     FACTORY_FOR = Answer
 
     poll = factory.SubFactory(PollFactory)
